local addon, s = ...

--[[//////////////////////////////////////////////////

    GLO-LO

----\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\]]

local ITEM_QUALITY_COLORS = ITEM_QUALITY_COLORS

--[[//////////////////////////////////////////////////

    BANK'S WATCH

    This is a lightweight add-on to keep track of your
    bank, reagent, void storage, guild bank, auctions,
    and mail inventory.

    The add-on will load and work directly with the
    saved variable rather than load it into memory,
    except for the tooltip cache.

----\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\]]

s[1] = {} -- B, functions, constants, variables
s[2] = {} -- L, localization
s[3] = {
    ['bank'] = false,-- T, globals
    ['reagent'] = false,
    ['void'] = false, 
    ['guild'] = false,
    ['player'] = false,
    ['auctions'] = false,
    ['mail'] = false,
    ['currency'] = false,

    ['icon'] = "Interface\\AddOns\\BanksWatch\\textures\\vault.tga",

    F = {}, -- Frames
    FRAMEWHITESPACE = 2,
    BUTTON_HEIGHT = 32,
    ROW = 12,
    NUM_REAGENT_SLOTS = 98,
    NUM_VOID_SLOTS = VOID_STORAGE_MAX or 80,
    REAGENT_PAGES = 1,
    VOID_PAGES = VOID_STORAGE_PAGES or 2,
    BACKPACK_CONTAINER = BACKPACK_CONTAINER,
    BANK_CONTAINER = BANK_CONTAINER,
    REAGENTBANK_CONTAINER = REAGENTBANK_CONTAINER,
    ITEM_INVENTORY_BANK_BAG_OFFSET = ITEM_INVENTORY_BANK_BAG_OFFSET,
    MAX_GUILDBANK_TABS = MAX_GUILDBANK_TABS,
    MAX_GUILDBANK_SLOTS_PER_TAB = MAX_GUILDBANK_SLOTS_PER_TAB or 98,
    NUM_BANKGENERIC_SLOTS = NUM_BANKGENERIC_SLOTS,
    NUM_BANKBAGSLOTS = NUM_BANKBAGSLOTS,
    NUM_BAG_SLOTS = NUM_BAG_SLOTS,
    EQUIPMENT_SLOTS = 18,
    ACTIVE_TABLE = {},
    CONFIG = false,
    CLASS = false,
    RAID_CLASS_COLORS = RAID_CLASS_COLORS,
    ITEM_QUALITY_COLORS = ITEM_QUALITY_COLORS,

    CLASS_ICONS = {
        ['WARRIOR'] =       "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:0:64:0:64|t",
        ['MAGE'] =          "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:64:128:0:64|t",
        ['ROGUE'] =         "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:128:196:0:64|t",
        ['DRUID'] =         "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:196:256:0:64|t",
        ['HUNTER'] =        "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:0:64:64:128|t",
        ['SHAMAN'] =        "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:64:128:64:128|t",
        ['PRIEST'] =        "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:128:196:64:128|t",
        ['WARLOCK'] =       "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:196:256:64:128|t",
        ['PALADIN'] =       "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:0:64:128:196|t",
        ['DEATHKNIGHT'] =   "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:64:128:128:196|t",
        ['MONK'] =          "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:128:196:128:196|t",
        ['DEMONHUNTER'] =   "|TInterface\\WorldStateFrame\\ICONS-CLASSES:16:16:0:0:256:256:196:256:128:196|t"
    },

    ISBANKOPEN = false,
    ISGUILDOPEN = false,
    ISVOIDOPEN = false,
    ISMERCHANTOPEN = false,

    BANKTAB = {['r'] = 0.32, ['g'] = 0.15, ['b'] = 0.64, ['a'] = 1},
    REAGENTTAB = {['r'] = 0.34, ['g'] = 0.24, ['b'] = 0.49, ['a'] = 1},
    CHARTAB = {['r'] = 0.39, ['g'] = 0.24, ['b'] = 0.81, ['a'] = 1},
    VOIDTAB = {['r'] = 0.24, ['g'] = 0.24, ['b'] = 0.49, ['a'] = 1},
    GUILDTAB = {['r'] = 0.20, ['g'] = 0.17, ['b'] = 0.56, ['a'] = 1},
    TOOLTIP = {['r'] = ITEM_QUALITY_COLORS[6].r, ['g'] = ITEM_QUALITY_COLORS[6].g, ['b'] = ITEM_QUALITY_COLORS[6].b, ['a'] = 1},
    TOOLTIPAC = {['r'] = ITEM_QUALITY_COLORS[5].r, ['g'] = ITEM_QUALITY_COLORS[5].g, ['b'] = ITEM_QUALITY_COLORS[5].b, ['a'] = 1},

    THEME = {['r'] = 0.05, ['g'] = 0.05, ['b'] = 0.05, ['a'] = 0.5},
    TRANSPARENCY = {['r'] = 0, ['g'] = 0, ['b'] = 0, ['a'] = 0.5},
    TRANSPARENCY_SLOT = {['r'] = 0, ['g'] = 0, ['b'] = 0, ['a'] = 0.2},
    BORDER_SLOT = {['r'] = 0, ['g'] = 0, ['b'] = 0, ['a'] = 1},
    SOUNDS = {
        "Interface\\Addons\\BanksWatch\\Sounds\\Coins.mp3",
        "Interface\\Addons\\BanksWatch\\Sounds\\RetroCoins.mp3",
        "Interface\\Addons\\BanksWatch\\Sounds\\Treasure.mp3",
        "Interface\\Addons\\BanksWatch\\Sounds\\Treasure2.mp3"
    },

    FONTS = {
        "Interface\\Addons\\BanksWatch\\Fonts\\Play-Bold.ttf",
        "Interface\\Addons\\BanksWatch\\Fonts\\Play-Regular.ttf",
        ['quantity'] = "Interface\\Addons\\BanksWatch\\Fonts\\Play-Bold.ttf",
        ['quantityoutline'] = "OUTLINE"
    },

    FLAGS = {
        ['NONE'] = true,
        ['OUTLINE'] = true,
        ['THICKOUTLINE'] = true,
        ['MONOCHROME'] = true
    },

    BW = {
        ['items'] = {},
        ['lookup'] = {},
        ['lookuprequest'] = false,
        ['tooltipcache'] = {},
        ['status'] = nil,
        ['forceBankScan'] = false,
        ['total_elapsed'] = 0
    },

    MSGC = {
        ['ERROR'] = "|cffFF00E1",
        ['INFO'] = "|cff35FCB5",--"|cffB5EDFF",
        ['EVENT'] = "|cffFFBF00",--"|cff35FCB5",
        ['DEBUG'] = "|cffE0FC35",
        ['DEFAULT'] = "|cff30DFEF",
        ['BOOL'] = "|cff2BED48",
        ['WARN'] = "|cffDBD3AF"
    },

    QUALITY = {
        ['9d9d9d'] = 0,
        ['ffffff'] = 1,
        ['1eff00'] = 2,
        ['0070dd'] = 3,
        ['a335ee'] = 4,
        ['ff8000'] = 5,
        ['e6cc80'] = 6,
        ['00ccff'] = 7
    },

    OPTIONS = {
        ['iconsize'] = true,
        ['iconsizeslider'] = true,
        ['iconrow'] = true,
        ['iconrowslider'] = true,
        ['minimize'] = true,
        ['helptooltip'] = true,
        ['bankbagstoggle'] = true,
        ['bankbagtooltiptoggle'] = true,
        ['playerbagstoggle'] = true,
        ['playerbagtooltiptoggle'] = true,
        ['colorvoid'] = true,
        ['colorvoidlabel'] = true,
        ['colorbank'] = true,
        ['colorbanklabel'] = true,
        ['colorguild'] = true,
        ['colorguildlabel'] = true,
        ['colortooltipaccent'] = true,
        ['colorreagent'] = true,
        ['colorreagentlabel'] = true,
        ['colorcharacter'] = true,
        ['colorcharacterlabel'] = true,
        ['colortooltip'] = true,
        ['openbank'] = true,
        ['openplayer'] = true,
        ['enablesoundsmoneytracker'] = true,
        ['enablemoneytracker'] = true,
        ['moneysound'] = true,
        ['treasuresound'] = true,
        ['treasuresoundtracker'] = true,
        ['minimumsoundtracker'] = true,
        ['scalemoneytracker'] = true,
        ['enablesearchallfactions'] = true,
        ['enablesearchallservers'] = true,
        ['transparency'] = true,
        ['FontQuantity'] = true,
        ['FontQuantityOutline'] = true,
        ['transparencyslot'] = true,
        ['minimapicon'] = true,
        ['borderslot'] = true,
        ['basecolor'] = true,
        ['state'] = true
    },

    INVSLOTS = {
        "HEADSLOT",
        "NECKSLOT",
        "SHOULDERSLOT",
        "SHIRTSLOT",
        "CHESTSLOT",
        "WAISTSLOT",
        "LEGSSLOT",
        "FEETSLOT",
        "WRISTSLOT",
        "HANDSSLOT",
        "FINGER0SLOT",
        "FINGER1SLOT",
        "TRINKET0SLOT",
        "TRINKET1SLOT",
        "BACKSLOT",
        "MAINHANDSLOT",
        "SECONDARYHANDSLOT",
        "TABARDSLOT"
    },

    --[[ GetAuctionItemTimeLeft
     1 - Short (less than 30 minutes) -- Red
     2 - Medium (30 minutes to 2 hours) -- Yellow
     3 - Long (2 hours to 12 hours) -- Green
     4 - Very Long (more than 12 hours) -- Blue ]]
    TIMEINDEX = {1800, 7200, 43200, 172800},
    TIME = {
        [1800] = {['r'] = 0.80, ['g'] = 0.16, ['b'] = 0.10, ['a'] = 1},
        [7200] = {['r'] = 0.84, ['g'] = 0.75, ['b'] = 0.04, ['a'] = 1},
        [43200] = {['r'] = 0.15, ['g'] = 0.72, ['b'] = 0.14, ['a'] = 1},
        [172800] = {['r'] = 0.13, ['g'] = 0.40, ['b'] = 0.75, ['a'] = 1}
    } -- highest possible duration in seconds (48 hours is max in AH)
}
s[4] = {} -- E, events only
